==> vmd-0.95.tar.gz: vmd-0.95/src/GeometryMol.h <==
/***************************************************************************
 * RCS INFORMATION:
 *
 *      $RCSfile: GeometryMol.h,v $
 *      $Author: billh $        $Locker:  $                $State: Exp $
 *      $Revision: 1.1 $      $Date: 1995/03/04 05:33:08 $
 *
 ***************************************************************************
 * DESCRIPTION:
 *
 * A base class for all Geometry objects which measure information about
 * atoms in a molecule.  A molecule Geometry monitor is assumed to operate
 * on N atoms, and be able to calculate a single floating-point value for
 * those atoms.  (i.e. the angle formed by three atoms in space)
 *
 ***************************************************************************
 * REVISION HISTORY:
 *
 * $Log: GeometryMol.h,v $
 * Revision 1.1  1995/03/04  05:33:08  billh
 * Initial revision
 *
 ***************************************************************************/
#ifndef GEOMETRYMOL_H
#define GEOMETRYMOL_H

#include "Geometry.h"
extern class MoleculeList;
extern class Molecule;
extern class Displayable;


class GeometryMol : public Geometry {

protected:
  // list of molecules to use for data
  MoleculeList *molList;

  // location where to print value in the scene
  float valuePos[3];
  
  // name of molecule geometry monitor
  char *gmName;

  //
  // protected functions
  //

  // set the name of this item
  void set_name(void);

  // sort the elements in the list, so that the lowest atom index is first
  // (but preserve the relative order, i.e. a-b-c or c-b-a)
  void sort_items(void);

  // check whether the given molecule m & atom index a is OK
  // if OK, return Molecule pointer; otherwise, return NULL
  Molecule *check_mol(int m, int a);

  // for the given Molecule, find the TRANSFORMED coords for the given atom.
  // return Molecule pointer if successful, NULL otherwise.
  Molecule *transformed_atom_coord(int m, int a, float *);
  
  // for the given Molecule, find the UNTRANSFORMED coords for the given atom.
  // return Molecule pointer if successful, NULL otherwise.
  Molecule *normal_atom_coord(int m, int a, float *);

  // draws a line between the two given points
  void display_line(float *, float *, Displayable *);

  // print given text at current valuePos position
  void display_string(char *, Displayable *);

public:
  // constructor: # items, molecule list to use
  GeometryMol(int, int *, int *, MoleculeList *mlist);
  virtual ~GeometryMol(void);
  
  //
  // public virtual routines
  //
  
  // return the name of this geometry marker; by default, just blank
  virtual char *name(void) { return (gmName ? gmName : Geometry::name()); }

  // check whether the geometry value can still be calculated
  virtual int ok(void);

  // calculate a whole list of items, if this object can do so.  Return success.
  virtual int calculate_all(ResizeArray<float> &);

};

#endif

==> vmd-0.96.tar.gz: vmd-0.96/src/GeometryMol.h <==
/***************************************************************************
 *cr                                                                       
 *cr            (C) Copyright 1995 The Board of Trustees of the           
 *cr                        University of Illinois                       
 *cr                         All Rights Reserved                        
 *cr                                                                   
 ***************************************************************************/

/***************************************************************************
 * RCS INFORMATION:
 *
 *      $RCSfile: GeometryMol.h,v $
 *      $Author: billh $        $Locker:  $                $State: Exp $
 *      $Revision: 1.2 $      $Date: 95/03/24 18:50:00 $
 *
 ***************************************************************************
 * DESCRIPTION:
 *
 * A base class for all Geometry objects which measure information about
 * atoms in a molecule.  A molecule Geometry monitor is assumed to operate
 * on N atoms, and be able to calculate a single floating-point value for
 * those atoms.  (i.e. the angle formed by three atoms in space)
 *
 ***************************************************************************
 * REVISION HISTORY:
 *
 * $Log:	GeometryMol.h,v $
 * Revision 1.2  95/03/24  18:50:00  billh
 * Added copyright notice to top of file; made sure all virtual routines
 * are defined in the .C file, not in the .h file.
 * 
 * Revision 1.1  1995/03/04  05:33:08  billh
 * Initial revision
 *
 ***************************************************************************/
#ifndef GEOMETRYMOL_H
#define GEOMETRYMOL_H

#include "Geometry.h"
extern class MoleculeList;
extern class Molecule;
extern class Displayable;


class GeometryMol : public Geometry {

protected:
  // list of molecules to use for data
  MoleculeList *molList;

  // location where to print value in the scene
  float valuePos[3];
  
  // name of molecule geometry monitor
  char *gmName;

  //
  // protected functions
  //

  // set the name of this item
  void set_name(void);

  // sort the elements in the list, so that the lowest atom index is first
  // (but preserve the relative order, i.e. a-b-c or c-b-a)
  void sort_items(void);

  // check whether the given molecule m & atom index a is OK
  // if OK, return Molecule pointer; otherwise, return NULL
  Molecule *check_mol(int m, int a);

  // for the given Molecule, find the TRANSFORMED coords for the given atom.
  // return Molecule pointer if successful, NULL otherwise.
  Molecule *transformed_atom_coord(int m, int a, float *);
  
  // for the given Molecule, find the UNTRANSFORMED coords for the given atom.
  // return Molecule pointer if successful, NULL otherwise.
  Molecule *normal_atom_coord(int m, int a, float *);

  // draws a line between the two given points
  void display_line(float *, float *, Displayable *);

  // print given text at current valuePos position
  void display_string(char *, Displayable *);

public:
  // constructor: # items, molecule list to use
  GeometryMol(int, int *, int *, MoleculeList *mlist);
  virtual ~GeometryMol(void);
  
  //
  // public virtual routines
  //
  
  // return the name of this geometry marker; by default, just blank
  virtual char *name(void);

  // check whether the geometry value can still be calculated
  virtual int ok(void);

  // calculate a whole list of items, if this object can do so.  Return success.
  virtual int calculate_all(ResizeArray<float> &);

};

#endif
